# enhance-long 

## Description

This tool integrates the lowest cost and highest performance methods to enhance the ability of large languages to process long contexts.


## Install 
```
pip install enhance-long
```

